=======
gridjug
=======

.. image:: https://travis-ci.org/andsor/gridjug.svg?branch=master
   :target: https://travis-ci.org/andsor/gridjug
   :alt: Testing status

.. image:: https://coveralls.io/repos/andsor/gridjug/badge.svg?branch=master&service=github
   :target: https://coveralls.io/github/andsor/gridjug?branch=master
   :alt: Test coverage

.. image:: https://img.shields.io/pypi/v/gridjug.svg
  :target: https://pypi.python.org/pypi/gridjug
  :alt: PyPI version
  
.. image:: https://img.shields.io/pypi/pyversions/gridjug.svg
  :target: https://pypi.python.org/pypi/gridjug
  :alt: Python versions
  
.. image:: https://img.shields.io/pypi/status/gridjug.svg
  :target: https://pypi.python.org/pypi/gridjug
  :alt: Status

.. image:: https://img.shields.io/pypi/l/gridjug.svg
  :target: http://gridjug.readthedocs.org/en/stable/license.html
  :alt: License

.. image:: https://img.shields.io/github/release/andsor/gridjug.svg
  :target: https://github.com/andsor/gridjug/releases/latest
  :alt: Latest release on GitHub
  
.. image:: https://img.shields.io/github/tag/andsor/gridjug.svg
  :target: https://github.com/andsor/gridjug/tags
  :alt: Latest tag on GitHub

.. image:: https://img.shields.io/github/issues/andsor/gridjug.svg
  :target: https://github.com/andsor/gridjug/issues
  :alt: Open Issues on GitHub

.. image:: https://readthedocs.org/projects/gridjug/badge/?version=latest
   :target: http://gridjug.readthedocs.org/en/latest
   :alt: Documentation Status

.. image:: https://readthedocs.org/projects/gridjug/badge/?version=stable
   :target: http://gridjug.readthedocs.org/en/stable
   :alt: Documentation Status

.. image:: https://zenodo.org/badge/6089/andsor/gridjug.svg
   :target: https://zenodo.org/badge/latestdoi/6089/andsor/gridjug
   :alt: Citation

A light-weight wrapper to run Jug with GridMap on a Grid Engine cluster

* **Documentation**: http://gridjug.readthedocs.org
* **Setup**: http://gridjug.readthedocs.org/en/stable/setup.html
